Vaz has been created to open and enter any kind of data file into the development area and make it so easy for anyone to handle the dataframe after reading.  
It was written using pandas and tried to use very basic steps which can be understood by anyone, even Python beginners.
Please send me your feedback to this email: siadatisaman@gmail.com



....................................................................

Vaz means 'open' in the Mazani accent(Persian) in the northern regions. 

